sphinxcontrib_htmlhelp: Sphinx extension which outputs HTML help book
=====================================================================

Description
-----------

Sphinx extension which outputs HTML help book

License
-------

BSD
